# django-paddle

Django models and helpers for integrating Paddle.com subscriptions

**WORK IN PROGRESS, NOT SUITEABLE FOR PRODUCTION USE**

### Installation

Requires:

* Python 3.6 or higher
* Django 2.1.0 or higher

```
pip install django-paddle
```

### Usage

TBA

### Run tests

```
python runtests.py
```
